@@ -296,6 +296,8 @@ int main (argc, argv)
     int edac_clean1 = 0;
     int edac_size1 = 0;
     int prominit_done = 0;
+    int l1scrub = 0;
+    int l1scrubperiod = 0;
 #ifdef LYNXOS_TOOL
     char *lynxoshome = getenv( "ENV_PREFIX" );
     char lynxoshome_pre[1024];
@@ -961,6 +963,13 @@ int main (argc, argv)
             multiflags |= MULTIFLAG_SOFT;
 		    goto copyxlist;
 		}
+		else if (strcmp (argv[stat], "-l1scrub") == 0)
+		  {
+		    if ((stat + 1) < argc) {
+		      l1scrub = 1;
+		      l1scrubperiod = VAL (argv[++stat]);
+		    }
+		  }
 
 		else
 		  {
@@ -1096,6 +1105,7 @@ int main (argc, argv)
 		   "\n\t.global _memcfg1, _memcfg2, _memcfg3, _sdmemcfg1,  _memcaddr, _uart, _scaler,  _uaddr, _gptaddr, _irqmpaddr, _iserc32, _agga4, _doedac, _doft, _clean_ram0, _clean_ram0_size, _clean_ram1, _clean_ram1_size, _ddrspa_cfg1, _ddr2spa_cfg1, _ddr2spa_cfg3, _ddr2spa_cfg4, _dsustart, _dsutrace, _nopnp, _isddr, _pnp, _mp, _sdctrl_sdcfg, _spimcfg, _dsuctrl \n");
 	  fprintf (dumpfile,"\n\t.global _uartnr, _sparcleon0, _mpstart, freqkhz\n");
 	  fprintf (dumpfile,"\n\t.global _mpirqsel0, _mpirqsel1, ftsdctrl64_pwr, ftsdctrl64_cfg, ftsdctrl64_edac, ftahbram_cfg\n");
+	  fprintf (dumpfile,"\n\t.global _l1scrub, _l1scrubperiod\n");
       }
     fprintf (dumpfile, "\n\t.global ramsize, _stack, _entry\n");
     fprintf (dumpfile, "\t.global freq, configmsg, bmsg, noinit\n");
@@ -1147,6 +1157,10 @@ int main (argc, argv)
     fprintf (dumpfile, "\t.word\t%d\n", mp);
     fprintf (dumpfile, "_dsuctrl:\n");
     fprintf (dumpfile, "\t.word\t0x%x\n", 0xcf | (dsubreak ? 0x20 : 0) );
+    fprintf (dumpfile, "_l1scrub:\n");
+    fprintf (dumpfile, "\t.word\t%d\n", l1scrub);
+    fprintf (dumpfile, "_l1scrubperiod:\n");
+    fprintf (dumpfile, "\t.word\t%d\n", l1scrubperiod);
     
     
     if (leon)
